@@ -2,8 +2,12 @@
 #' @description Calculate the harmonic mean of a set of numbers.
 #' 
 #' @param x a numeric vector.
+#' @param w an optional numerical vector of weights the same length as \code{x}.
 #' @param na.rm a logical value indicating whether NA values should be stripped 
 #'   before the computation proceeds.
+#'   
+#' @note If zeroes are present in \code{x}, function will return approximation
+#'   with a warning. In this case, weights will not be used.
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #'  
@@ -13,24 +17,24 @@
 #' median(x)
 #' harmonic.mean(x)
 #' 
-#' @importFrom stats na.omit var
 #' @export
 #' 
-harmonic.mean <- function(x, na.rm = FALSE) {
-  #
-  # Calculate harmonic mean of vector x
-  # If any x < 0, then approximation used
-  #
-  #   9/15/2010
+harmonic.mean <- function(x, w = NULL, na.rm = FALSE) {
+  if(is.null(w)) w <- rep(1, length(x))
+  if(length(w) != length(x)) stop("length of 'x' and 'w' must be the same")
+  if(na.rm) {
+    i <- !is.na(x)
+    if(!any(i)) return(NA)
+    x <- x[i]
+    w <- w[i]
+  }
   
-  if(na.rm) x <- na.omit(x)
-  if(length(x) == 0) return(NA)
   hm <- if(all(x > 0)) {
-    length(x) / sum(1 / x)
+    sum(w) / sum(w / x)
   } else {
     warning("some values are <= 0, using approximation")
     inv.mean.x <- 1 / mean(x)
-    var.x <- var(x)
+    var.x <- stats::var(x)
     1 / (inv.mean.x + var.x * inv.mean.x ^ 3)
   }
   ifelse(is.nan(hm), NA, hm)
